@@ -113,15 +113,11 @@ namespace gr {
               uint8_t change_flag = (uint8_t)((data[4] & 0xc0) >> 6);
               uint8_t occurrence_change = data[6];
               if (change_flag != 0)
-                GR_LOG_DEBUG(d_logger,
-                             format(", [CHANGE OF SUBCHANNEL OR SERVICE ORGA (%d)](at CIF %d) ") % (int) change_flag %
-                             (int) occurrence_change);
+                d_logger->debug(", [CHANGE OF SUBCHANNEL OR SERVICE ORGA ({})](at CIF {}) ",(int) change_flag,(int) occurrence_change);
               uint8_t alarm_flag = (uint8_t)((data[4] & 0x20) >> 5);
               if (alarm_flag == 1) GR_LOG_DEBUG(d_logger, ", [ALARM MESSAGE ACCESSIBLE] ");
               uint16_t CIF_counter = (uint16_t)((data[4] & 0x1f) * 250 + (data[5]));
-              GR_LOG_DEBUG(d_logger,
-                           format("ensemble info: reference %d, country ID %d, CIF counter = %d") % ensemble_reference %
-                           (int) country_ID % CIF_counter);
+              d_logger->debug("ensemble info: reference {}, country ID {}, CIF counter = {}",ensemble_reference,(int) country_ID,CIF_counter);
               break;
             }
             case FIB_MCI_EXTENSION_SUBCHANNEL_ORGA: {
@@ -136,18 +132,15 @@ namespace gr {
                   uint8_t table_switch = (uint8_t)(data[4 + subch_counter] & 0x40);
                   if (table_switch != 0) GR_LOG_DEBUG(d_logger, " [WARNING: OTHER TABLE USED] ");
                   uint8_t table_index = (uint8_t)(data[4 + subch_counter] & 0x3f);
-                  GR_LOG_DEBUG(d_logger, format("subchID = %d , start address = %d, index %d") % (int) subchID %
-                                         (int) start_address % (int) table_index);
+                  d_logger->debug("subchID = {} , start address = {}, index {}",(int) subchID,(int) start_address,(int) table_index);
                   subch_counter += 3;
                 } else {
                   uint8_t option = (uint8_t)(data[4 + subch_counter] & 0x70);
                   uint8_t protect_level = (uint8_t)((data[4 + subch_counter] & 0x0c) >> 2);
                   uint16_t subch_size = (uint16_t)((data[4 + subch_counter] & 0x03) << 8) |
                                         (uint8_t)(data[5 + subch_counter]);
-                  GR_LOG_DEBUG(d_logger,
-                               format("subchID = %d , start address = %d, option %d, protect level %d, subch size %d") %
-                               (int) subchID % (int) start_address % (int) option % (int) protect_level %
-                               (int) subch_size);
+                  d_logger->debug("subchID = {} , start address = {}, option {}, protect level {}, subch size {}",(int) subchID,
+                    (int) start_address,(int) option,(int) protect_level,(int) subch_size);
                   subch_counter += 4;
 
                   // write sub-channel info to json
@@ -186,22 +179,21 @@ namespace gr {
               do { //iterate over services
                 uint16_t service_reference = (uint16_t)(data[service_counter + 1] & 0x0f) << 8 |
                                              (uint8_t) data[service_counter + 2];
-                GR_LOG_DEBUG(d_logger, format("service orga: reference %d ") % service_reference);
+                d_logger->debug("service orga: reference {} ",service_reference);
                 uint8_t local_flag = (uint8_t)((data[service_counter + 3] & 0x80) >> 7);
                 if (local_flag == 1) GR_LOG_DEBUG(d_logger, "[LOCAL FLAG SET] ");
                 uint8_t ca = (uint8_t)((data[service_counter + 3] & 0x70) >> 4);
                 if (ca != 0) GR_LOG_DEBUG(d_logger, "[CONDITIONAL ACCESS USED] ");
                 uint8_t num_service_comps = (uint8_t)(data[service_counter + 3] & 0x0f);
-                GR_LOG_DEBUG(d_logger, format("(%d components):") % (int) num_service_comps);
+                d_logger->debug("({} components):",num_service_comps);
                 for (int i = 0; i < num_service_comps; i++) { //iterate over service components
                   uint8_t TMID = (uint8_t)((data[service_counter + 4 + i * 2] & 0xc0) >> 6);
                   uint8_t comp_type = (uint8_t)(data[service_counter + 4 + i * 2] & 0x3f);
                   uint8_t subchID = (uint8_t)((data[service_counter + 5 + i * 2] & 0xfc) >> 2);
                   uint8_t ps = (uint8_t)((data[service_counter + 5 + i * 2 + 1] & 0x02) >> 1);
                   if (TMID == 0) {
-                    GR_LOG_DEBUG(d_logger,
-                                 format("(audio stream, type %d, subchID %d, primary %d)") % (int) comp_type %
-                                 (int) subchID % (int) ps);
+                    d_logger->debug("(audio stream, type {}, subchID {}, primary {})",(int) comp_type,
+                                 (int) subchID,(int) ps);
                     // write service info from specififc subchannel to json
                     if (d_service_info_written_trigger < 0) {
                       d_service_info_written_trigger = (int) subchID;
@@ -221,12 +213,10 @@ namespace gr {
                       }
                     }
                   } else if (TMID == 1) {
-                    GR_LOG_DEBUG(d_logger,
-                                 format("(data stream, type %d, subchID %d, primary %d)") % (int) comp_type %
-                                 (int) subchID % (int) ps);
+                    d_logger->debug("(data stream, type {}, subchID {}, primary {})",(int) comp_type,
+                                 (int) subchID,(int) ps);
                   } else if (TMID == 2) {
-                    GR_LOG_DEBUG(d_logger,
-                                 format("(FIDC, type %d, subchID %d, primary %d)") % (int) comp_type % (int) subchID %
+                    d_logger->debug("(FIDC, type {}, subchID {}, primary {})",(int) comp_type,(int) subchID,
                                  (int) ps);
                   } else {
                     GR_LOG_DEBUG(d_logger, "[packed data]");
@@ -253,16 +243,14 @@ namespace gr {
                 uint8_t SCIdS = (uint8_t)(data[service_comp_counter + 4] & 0x0f);
                 if ((data[service_comp_counter + 5] & 0x80) == 0) {
                   uint8_t subchID = (uint8_t)(data[service_comp_counter + 5] & 0x3f);
-                  GR_LOG_DEBUG(d_logger,
-                               format("service component global definition: reference %d, SCIdS %d, subchID %d") %
-                               service_reference % (int) SCIdS % (int) subchID);
+                  d_logger->debug("service component global definition: reference {}, SCIdS {}, subchID {}", 
+                    service_reference,(int) SCIdS,(int) subchID);
                   service_comp_counter += 5;
                 } else {
                   uint16_t subchID = (uint16_t)(data[service_comp_counter + 5] & 0x0f) << 8 |
                                      (uint8_t) data[service_comp_counter + 6];
-                  GR_LOG_DEBUG(d_logger,
-                               format("service component global definition: reference %d, SCIdS %d, subchID %d") %
-                               service_reference % (int) SCIdS % (int) subchID);
+                  d_logger->debug("service component global definition: reference {}, SCIdS {}, subchID {}",
+                               service_reference,(int) SCIdS,(int) subchID);
                   service_comp_counter += 6;
                 }
               } while (1 + service_comp_counter < length);
@@ -281,12 +269,12 @@ namespace gr {
               GR_LOG_DEBUG(d_logger, "programme number");
               break;
             case FIB_SI_EXTENSION_PROGRAMME_TYPE: {
-              GR_LOG_DEBUG(d_logger, format("programme type, %d components") %((length-1)/4));
+              d_logger->debug("programme type, {} components",((length-1)/4));
               for(int i = 0; i < (length-1)/4; i++) {
                 uint8_t programme_type = (uint8_t)(data[2 + i*4 + 3] & 0x1f);
                 uint16_t service_reference = (uint16_t)(data[2 + i*4] & 0x0f) << 8 |
                                              (uint8_t) data[2 + i*4 + 1];
-                GR_LOG_DEBUG(d_logger, format("reference %d, type: %d") %service_reference %(int)programme_type);
+                d_logger->debug("reference {}, type: {}",service_reference,(int)programme_type);
 
                 // write programme type to json
                 if (d_programme_type_written_trigger < 0) {
@@ -315,7 +303,7 @@ namespace gr {
               GR_LOG_DEBUG(d_logger, "announcement switching");
               break;
             default:
-              GR_LOG_DEBUG(d_logger, format("unsupported extension (%d)") % (int) extension);
+              d_logger->debug("unsupported extension ({})",(int) extension);
               break;
           }
           break;
@@ -329,7 +317,7 @@ namespace gr {
             case FIB_SI_EXTENSION_ENSEMBLE_LABEL: {
               uint8_t country_ID = (uint8_t)((data[2] & 0xf0) >> 4);
               memcpy(label, &data[4], 16);
-              GR_LOG_DEBUG(d_logger, format("[ensemble label](%d): %s") % (int) country_ID % label);
+              d_logger->debug("[ensemble label]({}): {}",(int) country_ID,label);
               // write json for ensemble label and country ID
               std::stringstream ss;
               ss << "{" << "\"" << label << "\":{" << "\"country_ID\":" << (int) country_ID << "}}";
@@ -343,8 +331,7 @@ namespace gr {
                 if ((label[i] >= 'A' && label[i] <= 'Z') || (label[i] >= 'a' && label[i] <= 'z') || (label[i] >= '0' && label[i] <= '9') || label[i] == ' ') { }
                 else label[i] = '.'; // Temporarily replacing invalid characters with . to avoid encoding problems in Python FIXME
               }
-              GR_LOG_DEBUG(d_logger,
-                           format("[programme service label] (reference %d): %s") % service_reference % label);
+              d_logger->debug("[programme service label] (reference {}): {}",service_reference,label);
               // write service labels from services to json
               if (d_service_labels_written_trigger < 0) {
                 d_service_labels_written_trigger = (int) service_reference;
@@ -366,14 +353,14 @@ namespace gr {
             }
             case FIB_SI_EXTENSION_SERVICE_COMP_LABEL:
               memcpy(label, &data[5], 16);
-              GR_LOG_DEBUG(d_logger, format("[service component label] %s") % label);
+              d_logger->debug("[service component label] {}",label);
               break;
             case FIB_SI_EXTENSION_DATA_SERVICE_LABEL:
               memcpy(label, &data[5], 16);
-              GR_LOG_DEBUG(d_logger, format("[data service label]: %s") % label);
+              d_logger->debug("[data service label]: {}",label);
               break;
             default:
-              GR_LOG_DEBUG(d_logger, format("[unknown extension (%d)") % (int) extension);
+              d_logger->debug("[unknown extension ({})",(int) extension);
               break;
           }
           break;
@@ -392,7 +379,7 @@ namespace gr {
               GR_LOG_DEBUG(d_logger, "EWS (emergency warning service) - not supported yet");
               break;
             default:
-              GR_LOG_DEBUG(d_logger, format("unsupported extension (%d)") % (int) extension);
+              d_logger->debug("unsupported extension ({})",(int) extension);
           }
           break;
         case FIB_FIG_TYPE_CA:
